@@ -1,3 +1,7 @@
+__copyright__ = 'Copyright 2021, 3Liz'
+__license__ = 'GPL version 3'
+__email__ = 'info@3liz.org'
+
 import re
 import shutil
 import urllib
@@ -121,12 +125,13 @@ class Remote:
         return plugins.get(plugin_name)
 
     def install(self, plugin_name, version="latest"):
-        print(f"Installation {plugin_name} {version}")
-
         xml_version = self.latest(plugin_name)
         if xml_version is None:
+            print(f"Plugin {plugin_name} {version} not found.")
             return
 
+        print(f"Installation {plugin_name} {version}")
+
         url = self.list_plugins[plugin_name].download_url
         file_name = self.list_plugins[plugin_name].file_name
 
@@ -157,3 +162,5 @@ class Remote:
         zip_file.unlink()
 
         print(f"\tOk {zip_file.name}")
+
+        return 0
