@@ -1,3 +1,7 @@
+__copyright__ = 'Copyright 2021, 3Liz'
+__license__ = 'GPL version 3'
+__email__ = 'info@3liz.org'
+
 import unittest
 
 from pathlib import Path
@@ -11,7 +15,7 @@ class PluginManager(unittest.TestCase):
         self.remote = Remote(Path('fixtures/plugins'))
 
     def test_list_remote(self):
-        self.assertListEqual(
+        self.assertCountEqual(
             ["https://my.url/plugins.xml", "https://my.repo/plugins.xml"],
             self.remote.remote_list())
 
